@@ -7,6 +7,7 @@ from typing import List
 
 from notecoin.okex.websocket.handle import BaseHandle
 from notecoin.okex.websocket.utils import get_local_timestamp
+
 from websocket import WebSocket, WebSocketException, create_connection
 
 
@@ -40,7 +41,10 @@ class BaseConnect:
 
     def handle_data(self, res):
         for handle in self.handles:
-            handle.solve(res)
+            try:
+                handle.solve(res)
+            except Exception as e:
+                logging.info(f'error:{e}')
 
     def ping(self):
         self.ws.send('ping')
