@@ -14,12 +14,13 @@ class BaseHandle:
         print(f"{get_local_timestamp()}\t{len(data)}")
         if 'event' in data:
             return False
-        channel = data['args']['channel']
+
+        channel = data['arg']['channel']
         if channel in self.channels:
             return self.handle(data)
 
     def handle(self, data) -> bool:
-        print(f"{data['args']['channel']}:{len(str(data))}")
+        print(f"{data['arg']['channel']}:{len(str(data))}")
         return True
 
 
