@@ -20,7 +20,8 @@ class OkexCoin:
 
     @staticmethod
     def instance_by_account(data):
-        okex = OkexCoin(coin_id=f"{data['ccy']}-USDT", count=float(data['availBal']))
+        okex = OkexCoin(coin_id=f"{data['ccy']}-USDT", count=float(data['availBal']),
+                        price=float(data['eqUsd']) / float(data['availBal']))
         return okex
 
     @staticmethod
